amici1 — amici1

# amici1

## Plugins

- lino : Lino (`lino`)

- staticfiles : Staticfiles (`django.contrib.staticfiles`)

- about : About (`lino.modlib.about`)

- jinja : Jinja templates (`lino.modlib.jinja`)

- printing : Printing (`lino.modlib.printing`)

- system : System (`lino.modlib.system`)

- contenttypes : Contenttypes (`django.contrib.contenttypes`)

- gfks : Gfks (`lino.modlib.gfks`)

- memo : Memo (`lino.modlib.memo`)

- react : React (`lino_react.react`)

- users : Users (`lino_amici.lib.users`)

- office : Office (`lino.modlib.office`)

- xl : Xl (`lino_xl.lib.xl`)

- countries : Places (`lino_xl.lib.countries`)

- contacts : Contacts (`lino_amici.lib.contacts`)

- checkdata : Checkdata (`lino.modlib.checkdata`)

- cal : Calendar (`lino_xl.lib.cal`)

- calview : Calendar view (`lino_xl.lib.calview`)

- weasyprint : WeasyPrint (`lino.modlib.weasyprint`)

- uploads : Uploads (`lino.modlib.uploads`)

- ledger : Accounting (`lino_xl.lib.ledger`)

- sepa : SEPA (`lino_xl.lib.sepa`)

- addresses : Addresses (`lino_xl.lib.addresses`)

- phones : Contact Details (`lino_xl.lib.phones`)

- households : Households (`lino_amici.lib.households`)

- humanlinks : Parency links (`lino_xl.lib.humanlinks`)

- courses : Activities (`lino_xl.lib.courses`)

- topics : Topics (`lino_xl.lib.topics`)

- lists : Lists (`lino_xl.lib.lists`)

- blogs : Blog (`lino_xl.lib.blogs`)

- excerpts : Excerpts (`lino_xl.lib.excerpts`)

- export_excel : Export to Excel xls format (`lino.modlib.export_excel`)

- appypod : Appy POD (`lino_xl.lib.appypod`)

- comments : Comments (`lino.modlib.comments`)

- dashboard : Dashboard (`lino.modlib.dashboard`)

- amici : Amici (`lino_amici.lib.amici`)

- sessions : Sessions (`django.contrib.sessions`)

## Database models

- system.SiteConfig (Site configuration) : SiteConfig(id, default_build_method, simulate_today, site_company)

- contenttypes.ContentType (content type) : ContentType(id, app_label, model)

- gfks.HelpText (Help Text) : HelpText(id, content_type, field, help_text)

- users.User (User) : User(id, email, language, modified, created, start_date, end_date, password, last_login, username, user_type, initials, first_name, last_name, remarks, partner, time_zone, date_format, dashboard_layout)

- users.Authority (Authority) : Authority(id, user, authorized)

- countries.Country (Country) : Country(name, isocode, short_code, iso3, name_de, name_fr)

- countries.Place (Place) : Place(id, parent, name, country, zip_code, type, show_type, name_de, name_fr)

- contacts.Partner (Partner) : Partner(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks)

- contacts.CompanyType (Organization type) : CompanyType(id, name, abbr, abbr_de, abbr_fr, name_de, name_fr)

- contacts.RoleType (Function) : RoleType(id, name, can_sign, name_de, name_fr)

- contacts.Role (Contact person) : Role(id, type, person, company, start_date, end_date)

- contacts.Person (Person) : Person(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks, partner_ptr, title, first_name, middle_name, last_name, gender, birth_date)

- contacts.Company (Organization) : Company(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks, partner_ptr, parent, type)

- checkdata.Problem (Data problem) : Problem(id, user, owner_type, owner_id, checker, message)

- cal.RemoteCalendar (Remote Calendar) : RemoteCalendar(id, seqno, type, url_template, username, password, readonly)

- cal.Room (Room) : Room(id, name, company, contact_person, contact_role, display_color, description, name_de, name_fr)

- cal.EventType (Calendar entry type) : EventType(id, ref, seqno, name, attach_to_email, email_template, description, is_appointment, all_rooms, locks_user, force_guest_states, fill_presences, start_date, event_label, max_conflicting, max_days, transparent, planner_column, default_duration, event_label_de, event_label_fr, name_de, name_fr)

- cal.GuestRole (Guest role) : GuestRole(id, ref, name, name_de, name_fr)

- cal.Calendar (Calendar) : Calendar(id, name, description, color, name_de, name_fr)

- cal.Subscription (Subscription) : Subscription(id, user, calendar, is_hidden)

- cal.Task (Task) : Task(id, modified, created, start_date, start_time, user, owner_type, owner_id, summary, description, access_class, sequence, auto_type, priority, due_date, due_time, percent, state)

- cal.EventPolicy (Recurrency policy) : EventPolicy(id, start_date, start_time, end_date, end_time, name, every_unit, every, positions, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, event_type, name_de, name_fr)

- cal.RecurrentEvent (Recurring event) : RecurrentEvent(id, start_date, start_time, end_date, end_time, name, user, every_unit, every, positions, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, event_type, description, name_de, name_fr)

- cal.Event (Calendar entry) : Event(id, modified, created, start_date, start_time, end_date, end_time, build_time, build_method, user, assigned_to, owner_type, owner_id, summary, description, access_class, sequence, auto_type, priority, event_type, transparent, room, state)

- cal.Guest (Presence) : Guest(id, event, partner, role, state, remark)

- calview.DailyPlannerRow (Planner row) : DailyPlannerRow(id, seqno, designation, start_time, end_time, designation_de, designation_fr)

- uploads.Volume (Library volume) : Volume(id, ref, root_dir, base_url, description)

- uploads.UploadType (Upload type) : UploadType(id, name, upload_area, max_number, wanted, shortcut, name_de, name_fr)

- uploads.Upload (Upload file) : Upload(id, user, file, mimetype, file_size, owner_type, owner_id, upload_area, type, volume, library_file, description)

- ledger.LedgerInfo (ledger info) : LedgerInfo(user, entry_date)

- ledger.Journal (Journal) : Journal(id, ref, seqno, name, build_method, template, trade_type, voucher_type, journal_group, auto_check_clearings, auto_fill_suggestions, force_sequence, preliminary, account, partner, printed_name, dc, yearly_numbering, must_declare, uploads_volume, printed_name_de, printed_name_fr, name_de, name_fr)

- ledger.AccountingPeriod (Accounting period) : AccountingPeriod(id, ref, start_date, end_date, state, year, remark)

- ledger.FiscalYear (Fiscal year) : FiscalYear(id, ref, start_date, end_date, state)

- ledger.PaymentTerm (Payment term) : PaymentTerm(id, ref, name, days, months, end_of_month, printed_text, printed_text_de, printed_text_fr, name_de, name_fr)

- ledger.PaymentMethod (Payment method) : PaymentMethod(id, designation, journal, designation_de, designation_fr)

- ledger.Account (Account) : Account(id, ref, seqno, name, common_account, needs_partner, clearable, default_amount, name_de, name_fr)

- ledger.Voucher (Voucher) : Voucher(id, user, journal, entry_date, voucher_date, accounting_period, number, narration)

- ledger.Movement (Movement) : Movement(id, voucher, partner, seqno, account, amount, match, cleared, value_date)

- ledger.MatchRule (Match rule) : MatchRule(id, account, journal)

- sepa.Account (Bank account) : Account(id, partner, iban, bic, remark, primary)

- addresses.Address (Address) : Address(id, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, data_source, address_type, partner, remark, primary)

- phones.ContactDetail (Contact detail) : ContactDetail(id, start_date, end_date, detail_type, partner, value, remark, primary)

- households.Type (Household Type) : Type(id, name, name_de, name_fr)

- households.Household (Household) : Household(id, email, language, url, phone, gsm, fax, country, city, zip_code, region, addr1, street_prefix, street, street_no, street_box, addr2, prefix, name, remarks, payment_term, partner_ptr, type)

- households.Member (Household Member) : Member(id, start_date, end_date, title, first_name, middle_name, last_name, gender, birth_date, role, person, household, dependency, primary)

- humanlinks.Link (Personsl Link) : Link(id, type, parent, child)

- courses.Slot (Timetable Slot) : Slot(id, seqno, start_time, end_time, name)

- courses.Topic (Topic) : Topic(id, name, name_de, name_fr)

- courses.Line (Activity line) : Line(id, ref, name, company, contact_person, contact_role, excerpt_title, course_area, topic, description, every_unit, every, event_type, guest_role, body_template, description_de, description_fr, name_de, name_fr, excerpt_title_de, excerpt_title_fr)

- courses.Course (Activity) : Course(id, start_date, start_time, end_date, end_time, user, every_unit, every, positions, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, room, max_date, line, teacher, slot, description, remark, state, max_places, name, enrolments_until, description_de, description_fr)

- courses.Enrolment (Enrolment) : Enrolment(id, start_date, end_date, user, printed_by, course_area, course, pupil, request_date, state, places, remark, confirmation_details)

- topics.Interest (Interest) : Interest(id, owner_type, owner_id, topic, remark, partner)

- topics.Topic (Topic) : Topic(id, ref, name, description_text, description_text_de, description_text_fr, name_de, name_fr)

- lists.ListType (List Type) : Represents a possible choice for the list_type field of a `List`.

- lists.List (Partner List) : List(id, ref, designation, list_type, remarks, designation_de, designation_fr)

- lists.Member (List membership) : Member(id, seqno, list, partner, remark)

- blogs.EntryType (Blog Entry Type) : EntryType(id, name, important, remark, name_de, name_fr)

- blogs.Entry (Blog Entry) : A blog entry is a short article with a title, published on a given date and time by a given user.

- excerpts.ExcerptType (Excerpt Type) : ExcerptType(id, name, build_method, template, attach_to_email, email_template, certifying, remark, body_template, content_type, primary, backward_compat, print_recipient, print_directly, shortcut, name_de, name_fr)

- excerpts.Excerpt (Excerpt) : Excerpt(id, build_time, build_method, user, owner_type, owner_id, company, contact_person, contact_role, excerpt_type, language)

- comments.CommentType (Comment Type) : CommentType(id, name, name_de, name_fr)

- comments.Comment (Comment) : Comment(id, modified, created, user, owner_type, owner_id, body, body_short_preview, body_full_preview, reply_to, private, comment_type)

- comments.Mention (Mention) : Mention(id, modified, created, user, owner_type, owner_id, comment)

- comments.Reaction (Reaction) : Reaction(id, modified, created, user, comment, emotion)

- dashboard.Widget (Widget) : (no docstring)

- sessions.Session (session) : Django provides full support for anonymous sessions. The session framework lets you store and retrieve arbitrary data on a per-site-visitor basis. It stores data on the server side and abstracts the sending and receiving of cookies. Cookies contain a session ID – not the data itself.

## Actors

- core.Actor (Actor) : The base class for all actors. Subclassed by `AbstractTable`, `Table`, `ChoiceList` and `Frame`.

- core.Frame (Frame) : Base clase for actors which open a window which is neither a database table nor a detail form.

- core.AbstractTable (AbstractTable) : An AbstractTable is the definition of a tabular data view, usually displayed in a Grid (but it’s up to the user interface to decide how to implement this).

- core.VirtualTable (VirtualTable) : An `AbstractTable` that works on an volatile (non persistent) list of rows.

- core.VentilatedColumns (VentilatedColumns) : A mixin for tables that have a series of automatically generated columns

- core.VentilatingTable (VentilatingTable) : (no docstring)

- core.ButtonsTable (ButtonsTable) : Probably deprecated. Might not work as expected in React (because of hide_top_toolbar).

- core.ChoiceList (ChoiceList) : User-defined choice lists must inherit from this base class.

- core.Workflow (Workflow) : A workflow is a specialized choicelist used for defining the states of a workflow. Every choice is an instance of `State`.

- core.Table (Table) : An `AbstractTable` that works on a Django Model using a QuerySet.

- system.YesNo (Yes or no) : (no docstring)

- system.Genders (Genders) : (no docstring)

- system.PeriodEvents (Observed events) : (no docstring)

- system.DashboardLayouts (DashboardLayouts) : (no docstring)

- checkdata.Checkers (Data checkers) : (no docstring)

- printing.BuildMethods (BuildMethods) : (no docstring)

- utils.EmptyTable (EmptyTable) : A “Table” that has exactly one virtual row and thus is visible only using a Detail view on that row.

- utils.Report (Report) : A special kind of `EmptyTable` used to create “reports”. A report is a series of headings, paragraphs and tables combined into a single printable and previewable document.

- users.UserTypes (User types) : (no docstring)

- about.TimeZones (Time zones) : (no docstring)

- about.DateFormats (Date formats) : (no docstring)

- about.SiteSearch (Search) : (no docstring)

- about.About (About) : Display information about this web site. This defines the window which opens via the menu command Site ‣ About.

- system.SiteConfigs (Site configurations) : (no docstring)

- system.Dashboard (Dashboard) : (no docstring)

- gfks.ContentTypes (content types) : (no docstring)

- gfks.HelpTexts (Help Texts) : (no docstring)

- gfks.HelpTextsByModel (Help Texts) : (no docstring)

- gfks.BrokenGFKs (Broken GFKs) : (no docstring)

- gfks.BrokenGFKsByModel (Broken GFKs) : (no docstring)

- users.My (My) : Mixin for tables on `Authored` which sets the requesting user as default value for the `author` filter parameter.

- xl.Priorities (Priorities) : (no docstring)

- countries.PlaceTypes (PlaceTypes) : (no docstring)

- countries.Countries (Countries) : The table of all countries.

- countries.Places (Places) : (no docstring)

- countries.PlacesByPlace (Subdivisions) : (no docstring)

- countries.PlacesByCountry (Places) : (no docstring)

- uploads.Shortcuts (Upload shortcuts) : (no docstring)

- uploads.UploadAreas (Upload areas) : (no docstring)

- phones.ContactDetailTypes (Contact detail types) : (no docstring)

- contacts.PartnerEvents (Observed events) : (no docstring)

- contacts.CivilStates (Civil states) : (no docstring)

- contacts.Partners (Partners) : (no docstring)

- contacts.PartnersByCity (Partners) : (no docstring)

- contacts.PartnersByCountry (Partners) : (no docstring)

- contacts.Persons (Persons) : (no docstring)

- contacts.CompanyTypes (Organization types) : (no docstring)

- contacts.Companies (Organizations) : (no docstring)

- contacts.RoleTypes (Functions) : (no docstring)

- contacts.Roles (Contact persons) : (no docstring)

- contacts.RolesByCompany (Contact persons) : (no docstring)

- contacts.RolesByPerson (Contact for) : Shows all roles of a person.

- contacts.CompaniesByCompany (Child organisations) : (no docstring)

- checkdata.Problems (Data problems) : (no docstring)

- checkdata.AllProblems (Data problems) : Show all data problems.

- checkdata.ProblemsByOwner (Data problems) : Show data problems related to this database object.

- checkdata.ProblemsByChecker (Data problems) : Show the data problems by checker.

- checkdata.MyProblems (Data problems assigned to me) : (no docstring)

- cal.DisplayColors (Display colors) : (no docstring)

- cal.Weekdays (Weekdays) : (no docstring)

- cal.YearMonths (YearMonths) : (no docstring)

- cal.DurationUnits (DurationUnits) : (no docstring)

- cal.Recurrencies (Recurrencies) : (no docstring)

- cal.AccessClasses (Access classes) : (no docstring)

- cal.PlannerColumns (Planner columns) : (no docstring)

- cal.TaskStates (Task states) : (no docstring)

- cal.GuestStates (Presence states) : (no docstring)

- cal.EventEvents (Observed events) : (no docstring)

- cal.EntryStates (Entry states) : (no docstring)

- cal.ReservationStates (States) : (no docstring)

- cal.RemoteCalendars (Remote Calendars) : (no docstring)

- cal.Rooms (Rooms) : (no docstring)

- cal.AllRooms (Rooms) : (no docstring)

- cal.Calendars (Calendars) : (no docstring)

- cal.Subscriptions (Subscriptions) : (no docstring)

- cal.SubscriptionsByUser (Subscriptions) : (no docstring)

- cal.SubscriptionsByCalendar (Subscriptions) : (no docstring)

- cal.Tasks (Tasks) : (no docstring)

- cal.TasksByController (Tasks) : (no docstring)

- cal.TasksByUser (Tasks) : (no docstring)

- cal.MyTasks (My tasks) : (no docstring)

- cal.TasksByProject (Tasks) : (no docstring)

- cal.GuestRoles (Guest roles) : (no docstring)

- cal.Guests (Presences) : (no docstring)

- cal.AllGuests (Presences) : (no docstring)

- cal.GuestsByEvent (Presences) : (no docstring)

- cal.GuestsByRole (Presences) : (no docstring)

- cal.GuestsByPartner (Presences) : (no docstring)

- cal.MyPresences (My presences) : (no docstring)

- cal.MyPendingPresences (My pending invitations) : (no docstring)

- cal.MyGuests (My guests) : (no docstring)

- cal.EventTypes (Calendar entry types) : (no docstring)

- cal.RecurrentEvents (Recurring events) : (no docstring)

- cal.Events (Calendar entries) : (no docstring)

- cal.AllEntries (Calendar entries) : (no docstring)

- cal.EntriesByType (Calendar entries) : (no docstring)

- cal.ConflictingEvents ( ⚔ ) : (no docstring)

- cal.PublicEntries (Calendar entries) : (no docstring)

- cal.EntriesByDay (Appointments today) : (no docstring)

- cal.EntriesByRoom (Calendar entries) : (no docstring)

- cal.EntriesByController (Calendar entries) : (no docstring)

- cal.EntriesByGuest (Calendar entries) : (no docstring)

- cal.OneEvent (Calendar entries) : (no docstring)

- cal.MyEntries (My appointments) : (no docstring)

- cal.MyEntriesToday (My appointments today) : (no docstring)

- cal.MyAssignedEvents (Appointments assigned to me) : (no docstring)

- cal.OverdueAppointments (Overdue appointments) : (no docstring)

- cal.MyOverdueAppointments (My overdue appointments) : (no docstring)

- cal.MyUnconfirmedAppointments (My unconfirmed appointments) : (no docstring)

- cal.EventPolicies (Recurrency policies) : (no docstring)

- calview.Planners (Planners) : (no docstring)

- calview.DailyPlannerRows (Planner rows) : (no docstring)

- calview.ParameterClone (ParameterClone) : (no docstring)

- calview.DaysTable (DaysTable) : (no docstring)

- calview.DayNavigator (DayNavigator) : (no docstring)

- calview.CalendarView (CalendarView) : (no docstring)

- calview.DaySlave (DaySlave) : (no docstring)

- calview.DailySlaveBase (Daily planner) : (no docstring)

- calview.WeeklySlaveBase (Weekly planner) : (no docstring)

- calview.MonthlySlaveBase (Monthly planner) : (no docstring)

- calview.DailyPlanner (Daily planner) : (no docstring)

- calview.DailySlave (None) : (no docstring)

- calview.WeeklySlave (None) : (no docstring)

- calview.MonthlySlave (None) : (no docstring)

- calview.DailyView (Daily view) : (no docstring)

- calview.WeeklyView (Weekly view) : (no docstring)

- calview.MonthlyView (Monthly view) : (no docstring)

- uploads.Volumes (Library volumes) : (no docstring)

- uploads.UploadTypes (Upload types) : (no docstring)

- uploads.Uploads (Upload files) : (no docstring)

- uploads.AllUploads (Upload files) : (no docstring)

- uploads.UploadsByType (Upload files) : (no docstring)

- uploads.MyUploads (My Upload files) : (no docstring)

- uploads.AreaUploads (Upload files) : (no docstring)

- uploads.UploadsByController (Upload files) : (no docstring)

- ledger.DC (Booking directions) : (no docstring)

- ledger.JournalGroups (Journal groups) : (no docstring)

- ledger.PeriodStates (States) : (no docstring)

- ledger.CommonAccounts (Common accounts) : (no docstring)

- ledger.VoucherTypes (Voucher types) : (no docstring)

- ledger.TradeTypes (Trade types) : (no docstring)

- ledger.VoucherStates (Voucher states) : (no docstring)

- ledger.ItemsByVoucher (Content) : (no docstring)

- ledger.VouchersByPartnerBase (Partner vouchers) : Shows all ledger vouchers of a given partner.

- ledger.Accounts (Accounts) : (no docstring)

- ledger.Journals (Journals) : (no docstring)

- ledger.JournalsOverview (Journals) : (no docstring)

- ledger.ByJournal (ByJournal) : (no docstring)

- ledger.PrintableByJournal (PrintableByJournal) : (no docstring)

- ledger.AccountingPeriods (Accounting periods) : (no docstring)

- ledger.PaymentTerms (Payment terms) : (no docstring)

- ledger.PaymentMethods (Payment methods) : (no docstring)

- ledger.Vouchers (Vouchers) : (no docstring)

- ledger.AllVouchers (Vouchers) : (no docstring)

- ledger.MatchRules (Match rules) : (no docstring)

- ledger.MatchRulesByAccount (Match rules) : (no docstring)

- ledger.MatchRulesByJournal (Match rules) : (no docstring)

- ledger.ExpectedMovements (Debts) : (no docstring)

- ledger.DebtsByAccount (Debts) : (no docstring)

- ledger.DebtsByPartner (Debts) : (no docstring)

- ledger.PartnerVouchers (Vouchers) : (no docstring)

- ledger.AccountBalances (AccountBalances) : (no docstring)

- ledger.GeneralAccountBalances (General Account Balances) : (no docstring)

- ledger.PartnerBalancesByTradeType (Partners) : (no docstring)

- ledger.DebtorsCreditors (DebtorsCreditors) : (no docstring)

- ledger.Debtors (Debtors) : (no docstring)

- ledger.Creditors (Creditors) : (no docstring)

- ledger.Movements (Movements) : (no docstring)

- ledger.AllMovements (Movements) : (no docstring)

- ledger.MovementsByVoucher (Movements) : (no docstring)

- ledger.MovementsByPartner (Movements) : (no docstring)

- ledger.MyMovements (My movements) : (no docstring)

- ledger.MovementsByProject (Movements) : (no docstring)

- ledger.MovementsByAccount (Movements) : (no docstring)

- ledger.MovementsByMatch (Movements) : (no docstring)

- ledger.FiscalYears (Fiscal years) : (no docstring)

- sepa.Accounts (Bank accounts) : (no docstring)

- sepa.AccountsByPartner (Bank accounts) : (no docstring)

- addresses.AddressTypes (Address types) : (no docstring)

- addresses.DataSources (Data sources) : (no docstring)

- addresses.Addresses (Addresses) : (no docstring)

- addresses.AddressesByPartner (Addresses) : (no docstring)

- addresses.AddressesByCity (Addresses) : (no docstring)

- phones.ContactDetails (Contact details) : (no docstring)

- phones.ContactDetailsByPartner (Contact details) : (no docstring)

- households.MemberDependencies (Household Member Dependencies) : (no docstring)

- households.MemberRoles (Household member roles) : (no docstring)

- households.Types (Household Types) : (no docstring)

- households.Households (Households) : (no docstring)

- households.HouseholdsByType (Households) : (no docstring)

- households.Members (Household Members) : (no docstring)

- households.MembersByHousehold (Household Members) : (no docstring)

- households.SiblingsByPerson (Household composition) : (no docstring)

- households.MembersByPerson (Household memberships) : (no docstring)

- humanlinks.LinkTypes (Parency types) : (no docstring)

- humanlinks.Links (Personal Links) : (no docstring)

- humanlinks.LinksByHuman (Human Links) : (no docstring)

- courses.CourseStates (Activity states) : (no docstring)

- courses.EnrolmentStates (Enrolment states) : (no docstring)

- courses.ActivityLayouts (Course layouts) : (no docstring)

- topics.Topics (Topics) : (no docstring)

- topics.AllTopics (Topics) : (no docstring)

- topics.Interests (Interests) : (no docstring)

- topics.AllInterests (Interests) : (no docstring)

- topics.InterestsByPartner (Interests) : (no docstring)

- topics.InterestsByController (Interests) : (no docstring)

- topics.InterestsByTopic (Interests) : (no docstring)

- lists.ListTypes (List Types) : (no docstring)

- lists.Lists (Partner Lists) : (no docstring)

- lists.Members (List memberships) : (no docstring)

- lists.MembersByList (Members) : (no docstring)

- lists.MembersByPartner (List memberships) : (no docstring)

- lists.AllMembers (List memberships) : (no docstring)

- blogs.EntryTypes (Blog Entry Types) : (no docstring)

- blogs.Entries (Blog Entries) : (no docstring)

- blogs.MyEntries (My Blog Entries) : (no docstring)

- blogs.AllEntries (Blog Entries) : (no docstring)

- blogs.EntriesByType (Blog Entries) : (no docstring)

- blogs.EntriesByController (Blog Entries) : (no docstring)

- blogs.LatestEntries (Latest blog entries) : Show the most recent blog entries.

- excerpts.Shortcuts (Excerpt shortcuts) : (no docstring)

- excerpts.ExcerptTypes (Excerpt Types) : (no docstring)

- excerpts.Excerpts (Excerpts) : (no docstring)

- excerpts.AllExcerpts (Excerpts) : (no docstring)

- excerpts.MyExcerpts (My Excerpts) : (no docstring)

- excerpts.ExcerptsByType (Excerpts) : (no docstring)

- excerpts.ExcerptsByOwner (Existing excerpts) : (no docstring)

- comments.Emotions (Emotions) : (no docstring)

- comments.CommentEvents (Observed events) : (no docstring)

- comments.CommentTypes (Comment Types) : (no docstring)

- comments.Comments (Comments) : (no docstring)

- comments.MyComments (My Comments) : (no docstring)

- comments.AllComments (Comments) : (no docstring)

- comments.CommentsByX (Comments) : (no docstring)

- comments.RecentComments (Recent comments) : (no docstring)

- comments.CommentsByType (Comments) : (no docstring)

- comments.CommentsByRFC (Comments) : (no docstring)

- comments.CommentsByMentioned (Mentioned in) : (no docstring)

- comments.RepliesByComment (Replies) : (no docstring)

- comments.Mentions (Mentions) : (no docstring)

- comments.MentionsByOwner (Mentions) : (no docstring)

- comments.Reactions (Reactions) : (no docstring)

- dashboard.Widgets (Widgets) : (no docstring)

- dashboard.AllWidgets (All dashboard widgets) : (no docstring)

- dashboard.WidgetsByUser (Dashboard) : (no docstring)

- users.Users (Users) : (no docstring)

- users.AllUsers (Users) : (no docstring)

- users.UsersOverview (Users) : (no docstring)

- users.Me (My settings) : (no docstring)

- users.Authorities (Authorities) : (no docstring)

- users.AuthoritiesGiven (Authorities given) : (no docstring)

- users.AuthoritiesTaken (Authorities taken) : (no docstring)

- users.UserRoles (User roles) : (no docstring)

- users.Sessions (User sessions) : (no docstring)

- courses.Slots (Timetable Slots) : (no docstring)

- courses.Topics (Topics) : (no docstring)

- courses.Lines (Activity lines) : (no docstring)

- courses.LinesByTopic (Activity lines) : (no docstring)

- courses.EntriesByTeacher (Calendar entries) : Show calendar entries of activities led by this teacher

- courses.Activities (Activities) : (no docstring)

- courses.ActivitiesByLayout (Activities) : (no docstring)

- courses.AllActivities (Activities) : (no docstring)

- courses.ActivitiesByTeacher (Activities) : (no docstring)

- courses.MyActivities (My Activities) : (no docstring)

- courses.MyCoursesGiven (My courses given) : (no docstring)

- courses.ActivitiesByLine (Activities) : (no docstring)

- courses.ActivitiesByTopic (Activities) : (no docstring)

- courses.ActivitiesBySlot (Activities) : (no docstring)

- courses.DraftActivities (Draft activities) : (no docstring)

- courses.ActiveActivities (Current activities) : (no docstring)

- courses.InactiveActivities (Inactive courses) : (no docstring)

- courses.ClosedActivities (Closed courses) : (no docstring)

- courses.Enrolments (Enrolments) : (no docstring)

- courses.AllEnrolments (Enrolments) : (no docstring)

- courses.PendingRequestedEnrolments (Pending requested enrolments) : (no docstring)

- courses.PendingConfirmedEnrolments (Pending confirmed enrolments) : (no docstring)

- courses.EnrolmentsByPupil (Enrolments in Activities) : (no docstring)

- courses.EnrolmentsByCourse (Enrolments) : (no docstring)

- courses.EnrolmentsByOption (Enrolments using this option) : (no docstring)

- courses.StatusReport (Status Report) : Gives an overview about what’s up today .

- ledger.LedgerInfoTable (ledger infos) : (no docstring)